## Unix Examples
On unix systems the usage of the examples is very similar. The major difference is the usage of different BLAS backends (e.g. Apple Accelerate vs. Intel MKL). For the setup of the dependencies refer to:

### Setup Dependencies
* [macOS](setup/MAC.MD)
* [ubuntu](setup/UBUNTU.MD)

### Examples
* [__00 - Basic RL__: Dependency-free RL](examples/00_BASIC_RL.MD)
* [__01 - BLAS__: Accelerated RL](examples/01_BLAS.MD)


### Setup IDE
* [IDE (e.g. CLion)](setup/IDE.MD)


